==> infima_client-0.4.0-py3-none-any.whl: infima_client/models/latest_cohort_prediction.py <==
import datetime
from typing import Any, Dict, List, Type, TypeVar, Union, cast

import attr
from dateutil.parser import isoparse

from ..models.prediction_service_get_latest_cohort_simplified_response_200_simplified_prediction_pointforoutput import (
    PredictionService_GetLatestCohortSimplifiedResponse_200SimplifiedPredictionPointforoutput,
)
from ..types import UNSET, Unset

T = TypeVar("T", bound="LatestCohortPrediction")


@attr.s(auto_attribs=True)
class LatestCohortPrediction:
    """  """

    created_at: Union[Unset, datetime.datetime] = UNSET
    symbol: Union[Unset, str] = UNSET
    values: Union[
        Unset,
        List[
            PredictionService_GetLatestCohortSimplifiedResponse_200SimplifiedPredictionPointforoutput
        ],
    ] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        created_at: Union[Unset, str] = UNSET
        if not isinstance(self.created_at, Unset):
            created_at = self.created_at.isoformat()

        symbol = self.symbol
        values: Union[Unset, List[Any]] = UNSET
        if not isinstance(self.values, Unset):
            values = []
            for values_item_data in self.values:
                values_item = values_item_data.to_dict()

                values.append(values_item)

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if created_at is not UNSET:
            field_dict["createdAt"] = created_at
        if symbol is not UNSET:
            field_dict["symbol"] = symbol
        if values is not UNSET:
            field_dict["values"] = values

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        created_at = None
        _created_at = d.pop("createdAt", UNSET)
        if _created_at is not None:
            created_at = isoparse(cast(str, _created_at))

        symbol = d.pop("symbol", UNSET)

        values = []
        _values = d.pop("values", UNSET)
        for values_item_data in _values or []:
            values_item = PredictionService_GetLatestCohortSimplifiedResponse_200SimplifiedPredictionPointforoutput.from_dict(
                values_item_data
            )

            values.append(values_item)

        latest_cohort_prediction = cls(
            created_at=created_at,
            symbol=symbol,
            values=values,
        )

        latest_cohort_prediction.additional_properties = d
        return latest_cohort_prediction

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties

==> infima_client-0.39.0-py3-none-any.whl: infima_client/models/latest_cohort_prediction.py <==
import datetime
from typing import Any, Dict, List, Type, TypeVar, Union, cast

import attr
from dateutil.parser import isoparse

from ..models.prediction_service_get_latest_cohort_response_200_values_item import (
    PredictionService_GetLatestCohortResponse_200ValuesItem,
)
from ..types import UNSET, Unset

T = TypeVar("T", bound="LatestCohortPrediction")


@attr.s(auto_attribs=True)
class LatestCohortPrediction:
    """  """

    created_at: Union[Unset, datetime.datetime] = UNSET
    symbol: Union[Unset, str] = UNSET
    values: Union[
        Unset, List[PredictionService_GetLatestCohortResponse_200ValuesItem]
    ] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        created_at: Union[Unset, str] = UNSET
        if not isinstance(self.created_at, Unset):
            created_at = self.created_at.isoformat()

        symbol = self.symbol
        values: Union[Unset, List[Any]] = UNSET
        if not isinstance(self.values, Unset):
            values = []
            for values_item_data in self.values:
                values_item = values_item_data.to_dict()

                values.append(values_item)

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if created_at is not UNSET:
            field_dict["createdAt"] = created_at
        if symbol is not UNSET:
            field_dict["symbol"] = symbol
        if values is not UNSET:
            field_dict["values"] = values

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        created_at = None
        _created_at = d.pop("createdAt", UNSET)
        if _created_at is not None:
            created_at = isoparse(cast(str, _created_at))

        symbol = d.pop("symbol", UNSET)

        values = []
        _values = d.pop("values", UNSET)
        for values_item_data in _values or []:
            values_item = (
                PredictionService_GetLatestCohortResponse_200ValuesItem.from_dict(
                    values_item_data
                )
            )

            values.append(values_item)

        latest_cohort_prediction = cls(
            created_at=created_at,
            symbol=symbol,
            values=values,
        )

        latest_cohort_prediction.additional_properties = d
        return latest_cohort_prediction

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
